Enum MTLMultisampleStencilResolveFilter
Source #[repr(u32)]
pub enum MTLMultisampleStencilResolveFilter {
Sample0 = 0,
DepthResolvedSample = 1,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.